@@ -10,8 +10,8 @@ use strict;
 use warnings;
 
 package Devel::PerlySense::Util;
-{
-  $Devel::PerlySense::Util::VERSION = '0.0196';
+BEGIN {
+  $Devel::PerlySense::Util::VERSION = '0.0197';
 }
 use base "Exporter";
 
@@ -145,8 +145,9 @@ sub textRenderTemplate {
     my ($template, $rhParam) = @_;
 
     my $rex = join("|", map { quotemeta } sort keys %$rhParam);
+    my $rhParamEnv = { %ENV, %$rhParam };
 
-    $template =~ s/\${($rex)}/ $rhParam->{$1} || "" /eg;  ###TODO: should be //
+    $template =~ s/\${($rex)}/ $rhParamEnv->{$1} || "" /eg;  ###TODO: should be //
 
     return $template;
 }
